# SL Physics - 2

The course code for this page is **SPH4U7**.

## Magnetism

Magnets are objects with north/south dipoles that create a field around them. Although ferromagnetic substances can repel each other, paramagnetic substances are always attracted to a magnetic field. See [HL Chemistry#Physics properties of transition elements](/sch3uz/#physical-properties-of-transition-elements) for more details.

### Magnetic fields

<img src="/resources/images/magnetic-field.png" width=700>(Source: Kognity)</img>

Similar to electric and gravitational fields, magnetic fields (also known as **B-fields**) are drawn by their effect on a north pole. Since magnetic poles always appear in equal magnitude pairs, all magnetic field lines for a magnet must form closed loops from north to south **outside** and south to north **inside** the magnet. Much like electric field lines, magnetic field lines never touch

<img src="/resources/images/more-magnetic-fields.png" width=700>(Source: Kognity)</img>

Atoms in ferromagnetic materials are tiny magnets with **dipoles**. These dipoles act on neighbouring dipoles and can cause the whole object to align — this is known as an **electric domain**.

!!! note
    Nickel, cobalt, or any alloy with nickel, cobalt, or iron can become magnetised this way.

**Unmagnetised** domains have dipoles pointing in random directions that are aligned when exposed to a magnetic field where they become **magnetised** domains. As such, bar magnets are always broken into smaller magnets, each with two poles — a monopole is impossible to create.

### Straight-line electromagnets

Moving electric charges produce magnetic fields. A circle filled with an "x" indicates that the current is moving away from the viewer in the third dimension while a dotted circle indicates it is moving toward the viewer.

These magnetic fields are centred on the conductor, are in a plane perpendicular to the conductor, and have decreasing magnetic field strength over distance.

<img src="/resources/images/straight-line-electromagnet.png" width=700>(Source: Kognity)</img>

The **right-hand rule** for straight-line conductors indicates that when the conductor would be grasped by the right hand, the thumb would point in the direction of current and the fingers pointing in the direction of the magnetic field.

<img src="/resources/images/right-hand-rule.png" width=700>(Source: Kognity)</img>

### Selenoid electromagnets

A **selenoid** is a conductor coil in a tight helix. Current passed through a selenoid will generate a **uniform magnetic field** inside the coil with a pattern identical to that of a bar magnet outside it.

<img src="/resources/images/selenoid-electromagnet.png" width=700>(Source: Kognity)</img>

The right-hand rule can be applied again to a selenoid to identify the direction of the north pole or direction of magnetic field in the coil:

<img src="/resources/images/selenoid-right-hand-rule.png" width=700>(Source: Kognity)</img>

### Properties of moving charges

As only moving electric charges generate magnetic fields, stationary electric charges are **unaffected** by external magnetic fields. Moving charges are affected by Newton's third law of motion — equal and opposite forces are exerted on the charge and the magnet. As such, where $q$ is the charge of the particle and $\vec{v}\times \vec{B}$ is the **cross product** (vector multiplication) of the velocity of the particle and the magnetic field strength in Teslas:
$$\vec{F_m}=q\vec{v}\times \vec{B}$$

**Magnetic field strength** ($B$) represents the force acting per unit current in a conductor of unit length perpendicular to the field with the unit Tesla ($\pu{T}$)

The **magnetic force** is always plane **perpendicular** to both $\vec{v}$ and $\vec{B}$. Just the magnitude of the force can be found by using the angle between the two vectors ($\theta$):
$$|F_m|=qvB\sin\theta$$

Regardless of $\theta$, the force vector is always perpendicular to both $B$ and $v$,

The above equation can be rearranged to find **electromagnetic** force in terms of current and wire length in a **uniform magnetic field**:
$$|F_em|=BIL\sin\theta$$

<img src="/resources/images/magnet-on-wire.png" width=700>(Source: Kognity</img>

The **right-hand-rule** can be used to determine the direction of force — the thumb points in the direction of current/velocity, the fingers point in the direction of the magnetic field, and the palm points in the direction of force. Alternatively, just three fingers can be used.

<img src="/resources/images/right-hand-rule-forces.png" width=700>(Source: Kognity)</img>

When two straight-line conductors with current flowing through them are brought together, they either mutually attract or repel. The ampere is defined based on the current required to flow through a scenario involving two parallel straight-line conductors.

<img src="/resources/images/parallel-current-conductors.png" width=700>(Source: Kognity)</img>

Inside a **uniform magnetic field**, charges move in **uniform circular motion** at a constant velocity. If the particle did not enter the field at a perfect right angle, some of the velocity is used to change the path of the particle to be in a spiral — still perfectly circular, but additionally moving in the third dimension perpendicular to the circle.
$$\Sigma F_c = F_m$$

## Atomic, nuclear, and particle physics

### Atomic structure

!!! definition
    - A **photon** is a particle that represents light.
    - A **nucleon** is a subatomic particle in an atomic nucleus — that is, a proton or neutron.
    - A **nuclide** is a nucleus with a specific number of protons and neutrons.

Please see [HL Chemistry#2.1 - Atoms](/sch3uz/#21-atoms) and [HL Chemistry 1#2.2 - Electrons in atoms](/sch3uz/#22-electrons-in-atoms) for more information.

An electron in an atom will only become excited if a photon of exactly the right amount of energy strikes it. That energy can be found using the formula:
$$\Delta E=hf$$

where $E$ is the energy of the photon at frequency $f$, and $h$ is Planck's constant ($\pu{6.63\times 10^{-34} Js}$ or $\pu{4.14\times10^{-16} eVs}$).

An electron that de-excites will emit a photon of that exact energy and thus frequency to return to its previous state.

### Binding energy

According to Einstein's theory of special relativity:
$$\Delta E=\Delta mc^2$$

**Neutrons** in the nucleus hold the protons together via **strong nuclear forces** that somewhat act like glue. An increase in neutrons increases the strong nuclear force. In smaller nuclei, $N=Z$, but in larger nuclei, $N>Z$ as more neutrons are required to keep the nucleus stable as the number of protons increases.

The mass of a stable nucleus is always less than the sum of the masses of the individual nucleons (the **mass defect**) as some of the mass is converted to energy during the formation of a nucleus. The energy used is known as the **binding energy** of a nucleus.
$$E_\pu{binding} = \pu{mass defect}\times c^2$$

As such, the binding energy of a nucleus is also the energy required to separate it completely into individual nucleons.

Atomic mass is measured relative to the mass of a carbon-12 atom, which is exactly 12 u (unified atomic mass units).
$$\pu{1 u}=\pu{1.661\times10^{-27} kg}=\pu{9.315 MeVc^-2}$$

A higher **binding energy per nucleon** results in more energy required to break it apart and thus it being more stable.

<img src="/resources/images/binding-energy-curve.png" width=700>(Source: Kognity)</img>

!!! note
    It is required to know the general shape of the curve, that $\pu{~8.8 MeV}$ is the maximum, and that the end boundaries are $0$ and $\pu{~7.5 MeV}$. It is also required to know the elements at each of those points (hydrogen-1, iron-56/nickel-62, and uranium-238).

Since a greater binding energy per nucleon is more energetically favourable, nuclei to the right of iron-56 fission (split) while those to the left fuse (combine) to release energy — changes that would increase binding energy per nucleon are likely to occur because of this.

### Radioactive decay

!!! definition
    - An **alpha particle** is a helium-4 nucleus (2 protons, 2 neutrons).
    - A **beta particle** is an electron.
    - A **gamma ray** is a photon.

Radioactivity is the emission of **ionising** (will make ions) radiation due to changes of a nucleus. It is **random** and spontaneous — it is unaffected by external factors such as other nuclei decaying.

**Nuclear equations** are similar to chemical equations but show how nuclei change in a nuclear process by tracking the atomic and mass numbers. A nuclear equation is balanced so that the sum of the atomic and the sum of the mass numbers on both sides are equal.

$$A\to B+C$$

**Alpha decay** occurs when the strong nuclear force is unable to hold a large nucleus together and emits an alpha particle. The alpha particle is positive and can barely penetrate paper. The two particles move in opposite directions with momentums equal in magnitude.

<img src="/resources/images/alpha-decay.png" width=700>(Source: Kognity)</img>

$$\ce{^A_Z N → ^{A-4}_{Z-2} N' + ^4_2 He}$$

$\ce{^4_2 He}$ may be replaced by $\ce{^4_2\alpha}$.

!!! example
    Radium-226 alpha decays to radon-222.

**Beta-minus decay** ($\beta^-$) occurs when a neutron decays into a proton and releases a beta-minus particle (an electron and an electron antineutrino). It can penetrate up to 3 mm of aluminum. Where $\overline{v}_e$ is the antineutrino:

<img src="/resources/images/beta-minus-decay.png" width=700>(Source: Kognity)</img>

$$\ce{^1_0n → ^1_1p + ^0_{-1}e + ^0_0\overline{v}_e}$$

!!! note
    The bar over the electron antineutrino identifies it as an **antiparticle**.

The beta-minus particle can be written explicitly over the electron as $^0_{-1}\beta$.

In terms of the mother nucleus, the reaction results in the mass number staying the same while the atomic number increases by one.

**Beta-plus decay** ($\beta^+$) occurs when a proton decays into a neutron and releases a **positron** (an antielectron with a positive charge) and an electron neutrino ($v_e$)
$$\ce{^1_1p → ^1_0n + ^0_1e + ^0_0v_e}$$

The positron can be written as a beta-plus particle as $^0_1\beta$.

In terms of the mother nucleus, the reaction results in the mass number staying the same while the atomic number decreases by one. 

**Gamma decay** occurs when an excited nucleus transfers its energy to a high-energy photon with frequencies in the gamma region of the electromagnetic spectrum. There is no change in mass nor atomic number. A nuclide with an asterisk $*$ indicates it as excited. This emits *ionising radiation* which is not good for living beings.

<img src="/resources/images/gamma-decay.png" width=700>(Source: Kognity)</img>

$$\ce{^A_ZX^* → ^A_ZX + ^0_0\gamma}$$

### Detecting radiation

As radiation cannot be seen, it must be detected experimentally.

A **Geiger counter** utilises a gas-filled tube with a wire in the centre at high voltage. When a charged particle passes through, gas is ionised which cascade onto the wire to produce a pulse.

A **cloud chamber** contains vapour that turns into liquid droplets when ionising particles pass though, resulting in visible lines showing the path of the particles. A magnetic field can spiral the particle in a certain direction which allows for its charge to be identified.

### Half-life

The **half-life** of an element is the time required for half of the nuclides in a sample to decay — it is always the same no matter the number of initial nuclides.

As such, this means that the number of parent nuclei decreases by 50% of its current value each half-life.

<img src="/resources/images/half-life.png" width=700>(Source: Kognity)</img>

!!! example
    **Radioactive dating** analyses the ratio between carbon-14 and carbon-12 to determine the age of plant nmatter. As the ratio of C-14 and C-12 in the atmosphere has been relatively comstant, living plants maintain that balance by constantly exchanging carbon. Dead plants' carbon-14 slowly decay at a known rate, so the ratio can be used to determine the time since the plant died.

### Nuclear reactions

A nuclear reaction occurs when a nucleus is hit by another nucleus or subatomic particle and a different nuclide is formed (nuclear **transmutation**). In such a collision, energy and momentum must be conserved. Generally, neutrons are most commonly used in these reactions as they are not affected by Coulomb force exerted by the protons or electrons.

The **reaction energy** $Q$ is the difference in mass between the initial and final states multiplied by $c$ squared. In the sample reaction $a+X → Y+b$:
$$Q=[(M_a + M_X) - (M_Y + M_b)]c^2$$

 - If $Q$ is positive, the reaction is **exothermic** and will occur at any amount of initial kinetic energy.
 - If $Q$ is negative, an initial kinetic energy equal to $Q$ is required (the activation energy).

Nuclear **fusion** occurs when two lighter nuclei combine into a heavier one, releasing energy in the process.

Nuclear **fission** occurs when a heavy nucleus splits into two lighter nuclei. Along with some excess neutrons, energy is released. The two split pieces are usually somewhat unequal.

### Fission in reactors

The energy release of nuclei is very large — the energy density per unit mass is much higher than any other conventional source.

As nuclei get smaller, their stablility increases as the number of neutrons also decreases, so excess neutrons can set off a chain reaction by reacting with more nuclei.

<img src="/resources/images/fission-chain.gif" width=700>(Source: Kognity)</img>

However, neutrons that are ejected often have too much energy and must be **moderated** to slow down to prevent a critical mass where the number of reactions is self-sustaining, leading to overheating and reactor meltdown. A **moderator** is a material surrounding fuel rods to slow down incoming neutrons — usually heavy water.

**Control rods** are also inserted into the reaction core to control the rate of reaction. These absorb the neutrons from the moderator and the amount absorbed can be adjusted by raising the rods partially up to all the way from the reactor.

Nuclear power is superior to other types of energy generation in that:

 - it has a high power output due to high energy density
 - there are large reserves of nuclear fuel on Earth
 - there are no greenhouse gases emitted to generate power

Nuclear power has the following issues in that:

 - waste is highly radioactive with long half-lives, rendering removal and storage of nuclear waste a major issue
 - initial startup costs are expensive
 - strict maintenance is required due to the risk of nuclear meltdown
 - fissionable fuel can be recovered and used for destructive weapons
 - mining uranium is unhealthy — miners are exposed to harmful radiation and waste material from mines deemed not pure enough is not easy to dispose

### Nuclear fusion

Nuclear fusion generates energy per unit mass an order of magnitude greater than can be achieved with fission. The sun takes hydrogen and fuses it into helium. Heavier stars can fuse elements up to iron-56.
$$\ce{4 ^1_1 H → ^4_2 He + 2 e^+ + 2 v_e + 2\gamma}$$

Nuclear fusion power has the following issues in that it is currently unsustainable for more than a few secondsbecause:

 - the temperature required for the reaction is greater than 100 million degrees Celsius
 - it requires more energy input to heat the sample than is obtained from the fusion reaction
 - materials currently known cannot withstand the temperature making containment difficult — currently magnetic fields are used to hold the particles in place

## Resources

 - [IB Physics Data Booklet](/resources/g11/ib-physics-data-booklet.pdf)
 - [IB SL Physics Syllabus](/resources/g11/ib-physics-syllabus.pdf)
 - [Dealing with Uncertainties](/resources/g11/physics-uncertainties.pdf)
 - [External: IB Physics Notes](https://ibphysics.org)
